# NaroNet: discovery of tumor microenvironment elements from multiplex imaging.
Trained only with patient-level labels, NaroNet quantifies the phenotypes, neighborhoods, and neighborhood interactions that have the highest influence on the predictive task. This is the python implementation as described in our [*paper*](https://www.sciencedirect.com/science/article/pii/S1361841522000366).

### Installation
For GPU support, it is crucial to install the specific versions of CUDA that are compatible with the version of Pytorch.
For further information follow our [*github page*](https://github.com/djimenezsanchez/NaroNet) 

To install NaroNet:
```sh
pip install NaroNet
```